"""Auto-Subs: A powerful, local-first library for video transcription and subtitle generation."""

from auto_subs.api import generate, transcribe

__version__ = "0.3.0"

__all__ = ["__version__", "generate", "transcribe"]
